"""removed foreign key from user logged in

Peek Plugin Database Migration Script

Revision ID: 73d65f042834
Revises: 1176bc54abf3
Create Date: 2021-04-21 15:51:50.986641

"""

# revision identifiers, used by Alembic.
revision = "73d65f042834"
down_revision = "1176bc54abf3"
branch_labels = None
depends_on = None

from alembic import op


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint("uq_username", "UserLoggedIn")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_unique_constraint("uq_username", "UserLoggedIn", ["userName"])
    # ### end Alembic commands ###
