.plugin-user {
    min-height: 100vh;
    background-color: #f0f2f5;
    display: flex;
    align-items: center;
    justify-content: center;
    padding: 24px;
}

.logout-container {
    width: 100%;
    max-width: 400px;

    .user-info {
        display: flex;
        align-items: center;
        padding-bottom: 24px;
        border-bottom: 1px solid #f0f0f0;

        .user-avatar {
            font-size: 24px;
            margin-right: 16px;
        }

        .user-details {
            .user-label {
                color: rgba(0, 0, 0, 0.45);
                font-size: 14px;
                margin-bottom: 4px;
            }

            .user-name {
                color: rgba(0, 0, 0, 0.85);
                font-size: 16px;
                font-weight: 500;
            }
        }
    }

    .logout-actions {
        margin-top: 24px;

        .confirmation-text {
            display: block;
            text-align: center;
            color: rgba(0, 0, 0, 0.85);
            font-size: 16px;
            margin-bottom: 24px;
        }

        .button-group {
            display: flex;
            justify-content: flex-end;
            gap: 8px;
        }
    }
}
