:host {
    display: flex;
    justify-content: center;
    align-items: center;
    min-height: 100vh;
    padding: 16px;
    background-color: #f0f2f5;
}

.login-card {
    width: 100%;
    max-width: 400px;

    ::ng-deep .ant-card-body {
        padding: 24px;
    }

    h4 {
        text-align: center;
        margin-bottom: 24px;
        color: rgba(0, 0, 0, 0.85);
        font-weight: 500;
    }
}

.alert-message {
    margin-bottom: 16px;
}

.login-button {
    width: 100%;
    margin-top: 16px;
}

:host ::ng-deep {
    .ant-input-affix-wrapper {
        .anticon {
            color: rgba(0, 0, 0, 0.25);
        }

        &:hover,
        &:focus {
            .anticon {
                color: #40a9ff;
            }
        }
    }
}
